@@ -52,9 +52,11 @@ test_that("occ_download_cached utils", {
   expect_true(bb$expired)
   
   ## matched and not expired
+  # created: 2020-04-02, so set `age=(Sys.Date()-as.Date("2020-04-02"))+1`
   dprep3 <- occ_download_prep(pred_within("POLYGON((-14 42, 9 38, -7 26, -14 42))"),
     pred_gte("elevation", 5000))
-  cc <- dl_match(pred = dprep3, preds, age = 90)
+  age <- as.numeric((Sys.Date()-as.Date("2020-04-02"))+1)
+  cc <- dl_match(pred = dprep3, preds, age = age)
   expect_is(cc, "DownloadMatch")
   expect_true(cc$matched)
   expect_false(cc$expired)
@@ -88,9 +90,10 @@ test_that("occ_download_cached itself", {
   expect_equal(length(bb), 1)
 
   # match but expired
+  age <- as.numeric((Sys.Date()-as.Date("2020-04-02"))+1)
   expect_message((cc <- occ_download_cached(
       pred_within("POLYGON((-14 42, 9 38, -7 26, -14 42))"),
-      pred_gte("elevation", 5000), age = 90)),
+      pred_gte("elevation", 5000), age = age)),
     "match found \\(key"
   )
   # returns an object of class occ_download
